/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3) 
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details. 
 */

package org.dive4elements.river.exports.process;

import org.w3c.dom.Document;

import org.dive4elements.artifactdatabase.state.ArtifactAndFacet;
import org.dive4elements.river.exports.XYChartGenerator;

/**
 * A processor is intended to generate an output e.g. curve in a chart diagramm from
 * arbitrary data input which can be reused in several generators.
 *
 * @author <a href="mailto:bjoern.ricks@intevation.de">Björn Ricks</a>
 */
public interface Processor {

    /**
     * Processes data to generate e.g. a chart.
     *
     * @param generator XYChartGenerator to add output on.
     * @param aandf       The artifact and facet
     * @param theme      The theme that contains styling information.
     * @param visible       The visibility of the curve.
     * @param index        The index of the curve
     */
    public void doOut(
            XYChartGenerator generator,
            ArtifactAndFacet    aandf,
            Document             theme,
            boolean               visible,
            int                         index);

    /**
     * Returns true if the Processor class is able to generate output for a facet type
     *
     * @param facettype Name of the facet type
     * @return true if the facettype can be processed
     */
    public boolean canHandle(String facettype);
}
